import unittest

from nemonet.seleniumwebdriver.commands import Command


class MyTestCase(unittest.TestCase):

    def test_something(self):
        commando = Command()


if __name__ == '__main__':
    unittest.main()
